<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// T
	'tw_description' => 'Integrovať TextWheel do SPIPu',
	'tw_slogan' => 'Správa typografie SPIPu s modulom TextWheel',
];
